translate.storage.omegat.OmegaTUnit

Package translate :: Package storage :: Module omegat :: Class OmegaTUnit |
[hide private]
[frames] | no frames]

# Class OmegaTUnit

source code

An OmegaT translation memory unit

Instance Methods | [hide private]
__init__(self, source=None) Constructs a TranslationUnit containing the given source string. | source code
getdict(self) Get the dictionary of values for a OmegaT line | source code
setdict(self, newdict) Set the dictionary of values for a OmegaT line | source code
_get_field(self, key) | source code
_set_field(self, key, newvalue) | source code
__str__(self) str(x) | source code
istranslated(self) Indicates whether this unit is translated. | source code
Inherited from `base.TranslationUnit`: `__eq__`, `getcontext`, `getid`, `getunits`, `hasplural`, `isblank`, `isfuzzy`, `isheader`, `isreview`, `istranslatable`, `markfuzzy`, `markreviewneeded`, `merge`, `multistring_to_rich`, `unit_iter` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`
Source
getsource(self) | source code
setsource(self, newsource) Sets the source string to the given value. | source code
Inherited from `base.TranslationUnit`: `getsourcelanguage` Inherited from `base.TranslationUnit` (private): `_get_rich_source`, `_set_rich_source`
Target
gettarget(self) | source code
settarget(self, newtarget) Sets the target string to the given value. | source code
settargetlang(self, newlang) | source code
Inherited from `base.TranslationUnit`: `gettargetlanguage`, `gettargetlen` Inherited from `base.TranslationUnit` (private): `_get_rich_target`, `_set_rich_target`
Notes
getnotes(self, origin=None) Returns all notes about this unit. | source code
Inherited from `base.TranslationUnit`: `addnote`, `removenotes`
Locations
Inherited from `base.TranslationUnit`: `addlocation`, `addlocations`, `getlocations`
Errors
Inherited from `base.TranslationUnit`: `adderror`, `geterrors`

Class Methods | [hide private]
Inherited from `base.TranslationUnit`: `buildfromunit`, `rich_to_multistring`

Class Variables | [hide private]
Inherited from `base.TranslationUnit`: `rich_parsers`

Properties | [hide private]
| dict Get the dictionary of values for a OmegaT line
Inherited from `base.TranslationUnit`: `rid`, `xid` Inherited from `object`: `__class__`
Source
| source
Inherited from `base.TranslationUnit`: `rich_source`
Target
| target
| targetlang
Inherited from `base.TranslationUnit`: `rich_target`

Method Details | [hide private]

### __init__(self, source=None) (Constructor) | source code
Constructs a TranslationUnit containing the given source string. Overrides: object.__init__ (inherited documentation)

### setdict(self, newdict) | source code
Set the dictionary of values for a OmegaT line Parameters: `newdict` (Dict) - a new dictionary with OmegaT line elements

### getnotes(self, origin=None) | source code
Returns all notes about this unit. It will probably be freeform text or something reasonable that can be synthesised by the format. It should not include location comments (see getlocations()). Overrides: base.TranslationUnit.getnotes (inherited documentation)

### setsource(self, newsource) | source code
Sets the source string to the given value. Overrides: base.TranslationUnit.setsource (inherited documentation)

### settarget(self, newtarget) | source code
Sets the target string to the given value. Overrides: base.TranslationUnit.settarget (inherited documentation)

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)

### istranslated(self) | source code
Indicates whether this unit is translated. This should be used rather than deducing it from .target, to ensure that other classes can implement more functionality (as XLIFF does). Overrides: base.TranslationUnit.istranslated (inherited documentation)

Property Details | [hide private]

### dict Get the dictionary of values for a OmegaT line Get Method: getdict(self) - Get the dictionary of values for a OmegaT line Set Method: setdict(self, newdict) - Set the dictionary of values for a OmegaT line

### source Get Method: getsource(self) Set Method: setsource(self, newsource) - Sets the source string to the given value.

### target Get Method: gettarget(self) Set Method: settarget(self, newtarget) - Sets the target string to the given value.

### targetlang Set Method: settargetlang(self, newlang)